=====
Telix
=====

.. toctree::
   :maxdepth: 2
   :caption: User Guide

   intro
   session-manager
   keybindings
   macros
   triggers
   highlights
   room-mapping
   progressbars
   files
   protocols
   commands
   scripting
   scripting-api
   contributing
   history


Indexes
=======

* :ref:`genindex`
* :ref:`modindex`
